@@ -253,7 +253,10 @@ class Tethys(object):
 
     def get_results(self,
                     dataset_id: str,
-                    station_id: str,
+                    station_id: Optional[str] = None,
+                    geometry: Optional[dict] = None,
+                    lat: Optional[float] = None,
+                    lon: Optional[float] = None,
                     from_date: Union[str, pd.Timestamp, datetime, None] = None,
                     to_date: Union[str, pd.Timestamp, datetime, None] = None,
                     from_mod_date: Union[str, pd.Timestamp, datetime, None] = None,
@@ -270,81 +273,8 @@ class Tethys(object):
         ----------
         dataset_id : str
             The dataset_id of the dataset.
-        station_id : str
+        station_id : str or None
             The station_id of the associated station.
-        from_date : str, Timestamp, datetime, or None
-            The start date of the selection.
-        to_date : str, Timestamp, datetime, or None
-            The end date of the selection.
-        from_mod_date : str, Timestamp, datetime, or None
-            Only return data post the defined modified date.
-        to_mod_date : str, Timestamp, datetime, or None
-            Only return data prior to the defined modified date.
-        modified_date : bool
-            Should the modified dates be returned if they exist?
-        quality_code : bool
-            Should the quality codes be returned if they exist?
-        run_date : str or Timestamp
-            The run_date of the results to be returned. Defaults to None which will return the last run date.
-        remove_height : bool
-            Should the height dimension be removed from the output?
-        output : str
-            Output format of the results. Options are:
-                Dataset - return the entire contents of the netcdf file as an xarray Dataset,
-                DataArray - return the requested dataset parameter as an xarray DataArray,
-                Dict - return a dictionary of results from the DataArray,
-                json - return a json str of the Dict.
-
-        Returns
-        -------
-        Whatever the output was set to.
-        """
-
-        ## Get parameters
-        dataset = self._datasets[dataset_id]
-        parameter = dataset['parameter']
-        remote = self._remotes[dataset_id]
-
-        ## Get object key
-        obj_key = self._get_results_obj_key_s3(dataset_id, station_id, run_date)
-
-        ## Get results
-        ts_obj = get_object_s3(obj_key.iloc[0], remote['connection_config'], remote['bucket'], 'zstd')
-        xr3 = xr.open_dataset(ts_obj)
-
-        ## Filters
-        ts_xr1 = result_filters(xr3, from_date, to_date, from_mod_date, to_mod_date, remove_height)
-
-        if not 'station_id' in list(ts_xr1.coords):
-            ts_xr1 = ts_xr1.expand_dims('station_id').set_coords('station_id')
-
-        ## Output
-        output1 = process_results_output(ts_xr1, parameter, modified_date, quality_code, output)
-
-        return output1
-
-
-    def get_nearest_results(self,
-                    dataset_id: str,
-                    geometry: Optional[dict] = None,
-                    lat: Optional[float] = None,
-                    lon: Optional[float] = None,
-                    from_date: Union[str, pd.Timestamp, datetime, None] = None,
-                    to_date: Union[str, pd.Timestamp, datetime, None] = None,
-                    from_mod_date: Union[str, pd.Timestamp, datetime, None] = None,
-                    to_mod_date: Union[str, pd.Timestamp, datetime, None] = None,
-                    modified_date: Union[str, pd.Timestamp, datetime, None] = None,
-                    quality_code: Optional[bool] = False,
-                    run_date: Union[str, pd.Timestamp, datetime, None] = None,
-                    remove_height: Optional[bool] = False,
-                    output: str = 'Dataset'):
-        """
-        Function to query the time series data given a specific dataset_id and 2D point. A nearest neighbor query will be performed to find the single nearest station to the input point. Multiple optional outputs.
-
-        Parameters
-        ----------
-        dataset_id : str
-            The dataset_id of the dataset.
         geometry : dict or None
             A geometry in GeoJSON format. Can be either a point or a polygon. If it's a point, then the method will perform a nearest neighbor query and return one station.
         lat : float or None
@@ -378,32 +308,33 @@ class Tethys(object):
         -------
         Whatever the output was set to.
         """
+
         ## Get parameters
         dataset = self._datasets[dataset_id]
         parameter = dataset['parameter']
         remote = self._remotes[dataset_id]
 
-        ## Get all stations
-        if dataset_id not in self._stations:
-            stns = self.get_stations(dataset_id)
-
-        stn_dict = self._stations[dataset_id]
-
-        ## Spatial query
-        # Checks
         if isinstance(geometry, dict):
             geom_type = geometry['type']
         else:
             geom_type = None
 
-        if not ((geom_type == 'Point') or (isinstance(lat, float) and isinstance(lon, float))):
-            raise ValueError('geometry or a combination of lat and lon must be passed.')
+        if isinstance(station_id, str):
+            stn_id = station_id
+        elif ((geom_type == 'Point') or (isinstance(lat, float) and isinstance(lon, float))):
+            ## Get all stations
+            if dataset_id not in self._stations:
+                stns = self.get_stations(dataset_id)
 
-        # Run the spatial query
-        station_id = spatial_query(stn_dict, geometry, lat, lon)[0]
+            stn_dict = self._stations[dataset_id]
+
+            # Run the spatial query
+            stn_id = spatial_query(stn_dict, geometry, lat, lon)[0]
+        else:
+            raise ValueError('A station_id, geometry or a combination of lat and lon must be passed.')
 
         ## Get object key
-        obj_key = self._get_results_obj_key_s3(dataset_id, station_id, run_date)
+        obj_key = self._get_results_obj_key_s3(dataset_id, stn_id, run_date)
 
         ## Get results
         ts_obj = get_object_s3(obj_key.iloc[0], remote['connection_config'], remote['bucket'], 'zstd')
@@ -421,6 +352,103 @@ class Tethys(object):
         return output1
 
 
+    # def get_nearest_results(self,
+    #                 dataset_id: str,
+    #                 geometry: Optional[dict] = None,
+    #                 lat: Optional[float] = None,
+    #                 lon: Optional[float] = None,
+    #                 from_date: Union[str, pd.Timestamp, datetime, None] = None,
+    #                 to_date: Union[str, pd.Timestamp, datetime, None] = None,
+    #                 from_mod_date: Union[str, pd.Timestamp, datetime, None] = None,
+    #                 to_mod_date: Union[str, pd.Timestamp, datetime, None] = None,
+    #                 modified_date: Union[str, pd.Timestamp, datetime, None] = None,
+    #                 quality_code: Optional[bool] = False,
+    #                 run_date: Union[str, pd.Timestamp, datetime, None] = None,
+    #                 remove_height: Optional[bool] = False,
+    #                 output: str = 'Dataset'):
+    #     """
+    #     Function to query the time series data given a specific dataset_id and 2D point. A nearest neighbor query will be performed to find the single nearest station to the input point. Multiple optional outputs.
+
+    #     Parameters
+    #     ----------
+    #     dataset_id : str
+    #         The dataset_id of the dataset.
+    #     geometry : dict or None
+    #         A geometry in GeoJSON format. Can be either a point or a polygon. If it's a point, then the method will perform a nearest neighbor query and return one station.
+    #     lat : float or None
+    #         Instead of using the geometry parameter, optionally use lat and lon for the spatial queries. Both lat and lon must be passed for the spatial queries and will override the geometry parameter. If only lat and lon are passed, then the method performs a nearest neighbor query.
+    #     lon : float or None
+    #         See lat description.
+    #     from_date : str, Timestamp, datetime, or None
+    #         The start date of the selection.
+    #     to_date : str, Timestamp, datetime, or None
+    #         The end date of the selection.
+    #     from_mod_date : str, Timestamp, datetime, or None
+    #         Only return data post the defined modified date.
+    #     to_mod_date : str, Timestamp, datetime, or None
+    #         Only return data prior to the defined modified date.
+    #     modified_date : bool
+    #         Should the modified dates be returned if they exist?
+    #     quality_code : bool
+    #         Should the quality codes be returned if they exist?
+    #     run_date : str or Timestamp
+    #         The run_date of the results to be returned. Defaults to None which will return the last run date.
+    #     remove_height : bool
+    #         Should the height dimension be removed from the output?
+    #     output : str
+    #         Output format of the results. Options are:
+    #             Dataset - return the entire contents of the netcdf file as an xarray Dataset,
+    #             DataArray - return the requested dataset parameter as an xarray DataArray,
+    #             Dict - return a dictionary of results from the DataArray,
+    #             json - return a json str of the Dict.
+
+    #     Returns
+    #     -------
+    #     Whatever the output was set to.
+    #     """
+    #     ## Get parameters
+    #     dataset = self._datasets[dataset_id]
+    #     parameter = dataset['parameter']
+    #     remote = self._remotes[dataset_id]
+
+    #     ## Get all stations
+    #     if dataset_id not in self._stations:
+    #         stns = self.get_stations(dataset_id)
+
+    #     stn_dict = self._stations[dataset_id]
+
+    #     ## Spatial query
+    #     # Checks
+    #     if isinstance(geometry, dict):
+    #         geom_type = geometry['type']
+    #     else:
+    #         geom_type = None
+
+    #     if not ((geom_type == 'Point') or (isinstance(lat, float) and isinstance(lon, float))):
+    #         raise ValueError('geometry or a combination of lat and lon must be passed.')
+
+    #     # Run the spatial query
+    #     station_id = spatial_query(stn_dict, geometry, lat, lon)[0]
+
+    #     ## Get object key
+    #     obj_key = self._get_results_obj_key_s3(dataset_id, station_id, run_date)
+
+    #     ## Get results
+    #     ts_obj = get_object_s3(obj_key.iloc[0], remote['connection_config'], remote['bucket'], 'zstd')
+    #     xr3 = xr.open_dataset(ts_obj)
+
+    #     ## Filters
+    #     ts_xr1 = result_filters(xr3, from_date, to_date, from_mod_date, to_mod_date, remove_height)
+
+    #     if not 'station_id' in list(ts_xr1.coords):
+    #         ts_xr1 = ts_xr1.expand_dims('station_id').set_coords('station_id')
+
+    #     ## Output
+    #     output1 = process_results_output(ts_xr1, parameter, modified_date, quality_code, output)
+
+    #     return output1
+
+
     def get_bulk_results(self,
                          dataset_id: str,
                          station_ids: List[str],
